<?php
/*
Plugin Name: Auto Thickbox Plus
Plugin URI: http://attosoft.info/blog/en/auto-thickbox-plus/
Description: Overlays linked images on the current page in simple and fast effects. (improved version of Auto Thickbox Plugin, with some extra features)
Author: attosoft
Version: 0.5
Author URI: http://attosoft.info/en/
Text Domain: auto-thickbox
Domain Path: /lang
*/

/*  Copyright 2010-2011 attosoft (contact@attosoft.info)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/* This plugin is mainly based on Auto Thickbox Plugin by Denis de Bernardy.
   http://www.semiologic.com/software/auto-thickbox/
*/

load_plugin_textdomain('auto-thickbox', false, dirname(plugin_basename(__FILE__)) . '/lang');


/**
 * auto_thickbox
 *
 * @package Auto Thickbox
 **/

class auto_thickbox {
	/**
	 * filter()
	 *
	 * @param array $anchor
	 * @return anchor $anchor
	 **/

	function filter($anchor) {
		if ( preg_match("/\.(?:jpe?g|gif|png|bmp|webp)\b/i", $anchor['attr']['href']) )
			return auto_thickbox::image($anchor);
		elseif ( !empty($anchor['attr']['class']) && in_array('thickbox', $anchor['attr']['class']) )
			return auto_thickbox::iframe($anchor);
		else
			return $anchor;
	} # filter()
	
	
	/**
	 * image()
	 *
	 * @param array $anchor
	 * @return anchor $anchor
	 **/

	function image($anchor) {
		if ( get_option('thickbox_text') == 'manual' && !preg_match("/^\s*<\s*img\s.+?>\s*$/is", $anchor['body']) )
			return $anchor;
		
		if ( !$anchor['attr']['class'] ) {
			$anchor['attr']['class'][] = 'thickbox';
			$anchor['attr']['class'][] = 'no_icon';
		} else {
			if ( !in_array('thickbox', $anchor['attr']['class']) && !in_array('nothickbox', $anchor['attr']['class']) && !in_array('no_thickbox', $anchor['attr']['class']) )
				$anchor['attr']['class'][] = 'thickbox';
			if ( !in_array('no_icon', $anchor['attr']['class']) && !in_array('noicon', $anchor['attr']['class']) )
				$anchor['attr']['class'][] = 'no_icon';
		}
		
		if ( get_option('thickbox_style') == 'gallery' && in_the_loop() && !$anchor['attr']['rel'] )
			$anchor['attr']['rel'][] = 'gallery-' . get_the_ID();
		
		if ( empty($anchor['attr']['title']) ) {
			if ( preg_match("/\b(?:alt|title)\s*=\s*('|\")(.*?)\\1/i", $anchor['body'], $title) ) {
				$anchor['attr']['title'] = end($title);
			}
		}
		
		return $anchor;
	} # image()
	
	
	/**
	 * iframe()
	 *
	 * @return void
	 **/
	
	function iframe($anchor) {
		if ( strpos($anchor['attr']['href'], 'TB_iframe=true') !== false || strpos($anchor['attr']['href'], '#TB_inline') !== false )
			return $anchor;
		if ( strpos($anchor['attr']['href'], '://') === false || strpos($anchor['attr']['href'], $_SERVER['HTTP_HOST']) !== false )
			return $anchor; // not append 'TB_iframe=true' to URL in the same domain (i.e. display as not iframe but AJAX content)
		
		# strip anchor ref
		$href = explode('#', $anchor['attr']['href']);
		$anchor['attr']['href'] = array_shift($href);
		
		$anchor['attr']['href'] .= ( ( strpos($anchor['attr']['href'], '?') === false ) ? '?' : '&' )
			. 'TB_iframe=true' . ( count($href) == 0 ? '' : '#' . implode('#', $href) );
		
		return $anchor;
	} # iframe()
	
	
	/**
	 * scripts()
	 *
	 * @return void
	 **/

	function scripts() {
		if ( get_option('thickbox_res', 'load') == 'load' ) {
			wp_deregister_script('thickbox');
			wp_register_script('thickbox', plugins_url('thickbox.js', __FILE__), array('jquery'), '3.1-20110904', true);
		}
		wp_enqueue_script('thickbox');
		wp_localize_script('thickbox', 'thickboxL10n', array(
			'next' => __('Next &gt;', 'auto-thickbox'),
			'prev' => __('&lt; Prev', 'auto-thickbox'),
			'image' => __('Image', 'auto-thickbox'),
			'of' => __('of', 'auto-thickbox'),
			'close' => __('Close', 'auto-thickbox'),
			'l10n_print_after' => 'try{convertEntities(thickboxL10n);}catch(e){};'
		));
	} # scripts()
	
	
	/**
	 * styles()
	 *
	 * @return void
	 **/

	function styles() {
		if ( get_option('thickbox_res', 'load') == 'load' ) {
			wp_deregister_style('thickbox');
			wp_register_style('thickbox', plugins_url('thickbox.css', __FILE__), false, '20110904');
		}
		wp_enqueue_style('thickbox');
	} # styles()
	
	
	/**
	 * thickbox_images()
	 *
	 * @return void
	 **/

	function thickbox_images() {
		$includes_url = includes_url();
		
		echo <<<EOS

<script type="text/javascript">
var tb_pathToImage = "{$includes_url}js/thickbox/loadingAnimation.gif";
var tb_closeImage = "{$includes_url}js/thickbox/tb-close.png";
</script>

EOS;
	} # thickbox_images()
} # auto_thickbox

if ( !is_admin() && isset($_SERVER['HTTP_USER_AGENT']) &&
    	strpos($_SERVER['HTTP_USER_AGENT'], 'W3C_Validator') === false) {
	if ( !class_exists('anchor_utils') )
		include dirname(__FILE__) . '/anchor-utils/anchor-utils.php';
		
	add_action('wp_print_scripts', array('auto_thickbox', 'scripts'));
	add_action('wp_print_styles', array('auto_thickbox', 'styles'));
	
	add_action('wp_footer', array('auto_thickbox', 'thickbox_images'), 20);
	
	add_filter('filter_anchor', array('auto_thickbox', 'filter'));
}

/**
 * Auto Thickbox Plus
 * 
 * @author attosoft
 */
if ( is_admin() ) {
	add_action('admin_menu', 'auto_thickbox_menu');
	add_filter('plugin_row_meta', 'add_auto_thickbox_links', 10, 2);
}

// Auto Thickbox Plus Options
function auto_thickbox_menu() {
	add_options_page(__('Auto Thickbox Plus Options', 'auto-thickbox'), 'Auto Thickbox Plus', 8, __FILE__, 'auto_thickbox_options');
}
function auto_thickbox_options() {
	$thickbox_style = get_option('thickbox_style', 'single');
	$thickbox_text = get_option('thickbox_text', 'auto');
	$thickbox_res = get_option('thickbox_res', 'load');
?>
<div class="wrap">
	<?php screen_icon(); ?>
	<h2><?php _e('Auto Thickbox Plus Options', 'auto-thickbox'); ?></h2>
	<form method="post" action="options.php">
		<?php wp_nonce_field('update-options'); ?>
		<table class="form-table">
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('Default Display Style', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="radio" name="thickbox_style" value="single"<?php checked($thickbox_style, 'single'); ?> />
						<?php _e('Single Image (explicitly specify a@rel attribute as needed)', 'auto-thickbox'); ?></label><br />
					<label><input type="radio" name="thickbox_style" value="gallery"<?php checked($thickbox_style, 'gallery'); ?> />
						<?php _e('Gallery Images (automatically set a@rel attribute in \'gallery-id\' format)', 'auto-thickbox'); ?></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('ThickBox on Text Links', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="radio" name="thickbox_text" value="auto"<?php checked($thickbox_text, 'auto'); ?> />
						<?php _e('Auto (automatically set a@class=&quot;thickbox&quot;)', 'auto-thickbox'); ?></label><br />
					<label><input type="radio" name="thickbox_text" value="manual"<?php checked($thickbox_text, 'manual'); ?> />
						<?php _e('Manual (explicitly specify a@class=&quot;thickbox&quot; as needed)', 'auto-thickbox'); ?></label>
				</td>
			</tr>
			<tr style="vertical-align: top;">
				<th scope="row"><?php _e('ThickBox Resources (JS, CSS)', 'auto-thickbox'); ?></th>
				<td>
					<label><input type="checkbox" name="thickbox_res" value="load"<?php checked($thickbox_res, 'load'); ?> />
						<?php _e('Loads optimized (compressed &amp; tweaked) alternative resources (thickbox.js, thickbox.css)', 'auto-thickbox'); ?></label>
				</td>
			</tr>
		</table>
		<input type="hidden" name="action" value="update" />
		<input type="hidden" name="page_options" value="thickbox_style,thickbox_text,thickbox_res" />
		<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" /></p>
	</form>
</div>
<?php
}

// Additional links on the Plugins page
function add_auto_thickbox_links($links, $file) {
	if ( $file == plugin_basename(__FILE__) ) {
		$links[] = '<a href="http://wordpress.org/extend/plugins/auto-thickbox-plus/" target="_blank">' . __('Show Details') . '</a>';
		$links[] = '<a href="' . get_bloginfo('url') . '/wp-admin/options-general.php?page=' . $file .'">' . __('Settings') . '</a>';
		$links[] = '<a href="' . __('http://attosoft.info/blog/en/contact/', 'auto-thickbox') . '" target="_blank">' . __('Contact Me', 'auto-thickbox') . '</a>';
	}
	return $links;
}
?>